QEP Latent Variable Models
==========================

In QPyTorch, we can fit latent variable models based on q-exponential processes.
See the `Q-Exponential Latent Variable Model (QEP-LVM)`_ for example.
Interestingly, QEP-LVM learns latent representations regularized by the parameter :math:`q>0`: 
smaller :math:`q` leads to more compact latent representation.
Check this `QEP-LVM regularizes latent representations`_ notebook.

.. toctree::
   :maxdepth: 1
   :hidden:

   QExponential_Process_Latent_Variable_Models_with_Stochastic_Variational_Inference.ipynb
   QEP_LVM_for_Regularizing_Latent_Representations.ipynb

.. _Q-Exponential Latent Variable Model (QEP-LVM):
  ./QExponential_Process_Latent_Variable_Models_with_Stochastic_Variational_Inference.ipynb

.. _QEP-LVM regularizes latent representations:
  ./QEP_LVM_for_Regularizing_Latent_Representations.ipynb
